<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                	xmlns:tempuri="http://tempuri.org/ProjectDS.xsd"
                  xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                  xmlns:user="urn:my-scripts"
	                exclude-result-prefixes="tempuri">
  <xsl:param name="sFooterPath"/>

  <msxsl:script language="javascript" implements-prefix="user">
    <![CDATA[
        function GetAbs(val){
          return Math.abs(val);
        } 
        function GetSqrt(val){
          return Math.sqrt(val);
        } 
    ]]>
  </msxsl:script>
  
  <xsl:template match="/">
    <html class="no-js" lang="en">
      <head> 
        <meta charset="utf-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <title>GCD Report</title>
        <link rel="stylesheet" href="style.css" />
        <script src="js/modernizr.js"></script> 
      </head>
      <body>
        <div class="row">
          <div class="columns medium-3">
            <!-- The path below points to a broken link as this .png is not copied to the Images folder of the report-->
            <img class="demSurveyImage lightbox" src="Images/gcd_logo.png"></img>
          </div>
          <div class="columns medium-9">
            <h1>
              <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:Name"/>
            </h1>
            <h2 id="Title">
              GCD <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:GCDVersion"/> Analysis Report
            </h2> 
          </div>
        </div>
        <div class="row">
          <div class="medium-12 columns">
            <xsl:call-template name="toc_builder"/>
          </div>
        </div>
        <div class="row">
          <div id="ReportContainer" class="medium-12 columns">

            <xsl:apply-templates select="tempuri:ProjectDS/tempuri:Project"/>
            
            <h1>DEM Surveys</h1>
            <xsl:apply-templates select="tempuri:ProjectDS/tempuri:Project/tempuri:DEMSurvey"/>
            <h1>Change Detection Analyses</h1>   
            <h2>DEM of Difference</h2>    
            <xsl:apply-templates select="tempuri:ProjectDS/tempuri:Project/tempuri:DoDs"/>
            <xsl:call-template name="Appendices"/>
          </div>
        </div>
        <script src="js/report.js"></script>
      </body>
    </html>
  </xsl:template>

  <xsl:variable name="unit" select="tempuri:ProjectDS/tempuri:Project/tempuri:DisplayUnits" />

  <!-- Gives us a blank element for the javascript to build us a table of contents -->
  <xsl:template name="toc_builder">
    <div id="toc-wrapper">
      <h4>Table of Contents:</h4>
      <div id="toc"></div>
    </div>
  </xsl:template>

  <xsl:template match="tempuri:Project">
    <xsl:call-template name="ProjectOverviewTable"/>
  </xsl:template>


  <!-- Template for Project Overview  -->
  <xsl:template name="ProjectOverviewTable">
    <h3>Project Overview</h3>
    <p>
      <xsl:value-of select="tempuri:Description"/>
    </p>
    <table class="surface-table">
      <thead>
        <tr>
          <th>Name</th>
          <th>Value</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <td>Date Created</td>
          <td>
            <xsl:value-of select="tempuri:DateCreated"/>
          </td>
        </tr>
        <tr>
          <td>Output Directory</td>
          <td>
            <xsl:value-of select="tempuri:OutputDirectory"/>
          </td>
        </tr>
        <tr>
          <td>Precision</td>
          <td>
            <xsl:value-of select="tempuri:Precision"/>
          </td>
        </tr>
        <tr>
          <td>Display Units</td>
          <td>
            <xsl:value-of select="tempuri:DisplayUnits"/>
          </td>
        </tr>
        <tr>
          <td>Coordinate System</td>
          <td>
            <xsl:value-of select="tempuri:CoordinateSystem"/>
          </td>
        </tr>
        <tr>
          <td>Project Type</td>
          <td>
            <xsl:value-of select="tempuri:ProjectType"/>
          </td>
        </tr>
      </tbody>
    </table>
  </xsl:template>
  
  
  <!-- Template for each DEMSurvey node -->
  <xsl:template match="tempuri:DEMSurvey">
    <div class="DEMSurvey">
      <h2>
        <xsl:value-of select="tempuri:Name"/>
      </h2>
      <p>The following are the DEM and hillshade generated from survey one used in the change detection analysis.</p>
      <div class="row">
        <div class="surface-image columns medium-7">
          <img class="demSurveyImage lightbox">
            <xsl:attribute name="src">
              Images/<xsl:value-of select ="tempuri:Name"/>_<xsl:value-of select="tempuri:DEMSurveyID"/>.png
            </xsl:attribute>
          </img>
        </div>
        <div class="surface-table columns medium-5">
            <xsl:call-template name="DEMOverviewTable" />
        </div>
      </div>
      <xsl:if test="tempuri:AssociatedSurface">
        <h3>Associated Surfaces</h3>
        <xsl:copy-of select="$associatedSurfaceIntro" />
        <xsl:apply-templates select="tempuri:AssociatedSurface"/>
      </xsl:if>
      <xsl:if test="tempuri:ErrorSurface">
      <h3>Error Surfaces</h3>
        <xsl:copy-of select="$errorSurfaceIntro"/>
      <xsl:apply-templates select="tempuri:ErrorSurface"/>
      </xsl:if>
    </div>
  </xsl:template>

  <!-- DEM Table:-->
  <xsl:template name="DEMOverviewTable">
    <table class="surface-table">
      <thead>
        <tr>
          <th>Name</th>
          <th>Value</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <td>Raster Path</td>
          <td>
            <xsl:value-of select="tempuri:Source"/>
          </td>
        </tr>
        <xsl:if test="tempuri:SingleMethod = 'true'">
        <tr>          
            <td>Survey Method</td>
            <td><xsl:value-of select ="tempuri:SingleMethodType"/></td>
        </tr>
        </xsl:if>
        <xsl:if test="tempuri:MultiMethod = 'true'">
          <tr>
            <td>Multi Method Mask</td>
            <td>
              <xsl:value-of select ="tempuri:MethodMask"/>
            </td>
          </tr>
        </xsl:if>
        <tr>
          <td colspan="2" align="center"><b>DEM Extent</b></td>
        </tr>
        <tr>
          <td>Top</td>
          <td>
            <xsl:value-of select="tempuri:ExtentTop"/>
          </td>
        </tr>
        <tr>
          <td>Left</td>
          <td>
            <xsl:value-of select="tempuri:ExtentLeft"/>
          </td>
        </tr>
        <tr>
          <td>Right</td>
          <td>
            <xsl:value-of select="tempuri:ExtentRight"/>
          </td>
        </tr>
        <tr>
          <td>Bottom</td>
          <td>
            <xsl:value-of select="tempuri:ExtentBottom"/>
          </td>
        </tr>
        <tr>
          <td>Cell Size</td>
          <td>
            <xsl:value-of select="tempuri:CellResolution"/><xsl:text>&#xA0;</xsl:text>(<xsl:copy-of select="$DisplayUnits"/>)
        </td>
        </tr>
        <tr>
          <td colspan="2" align="center"><b>Original DEM Extent</b></td>
        </tr>
        <tr>
          <td>Top</td>
          <td>
            <xsl:value-of select="tempuri:OriginalExtentTop"/>
          </td>
        </tr>
        <tr>
          <td>Left</td>
          <td>
            <xsl:value-of select="tempuri:OriginalExtentLeft"/>
          </td>
        </tr>
        <tr>
          <td>Right</td>
          <td>
            <xsl:value-of select="tempuri:OriginalExtentRight"/>
          </td>
        </tr>
        <tr>
          <td>Bottom</td>
          <td>
            <xsl:value-of select="tempuri:OriginalExtentBottom"/>
          </td>
        </tr>
        <tr>
          <td>Original Source</td>
          <td>
            <xsl:value-of select="tempuri:OriginalSource"/>
          </td>
        </tr>
        <tr>
          <td>Original Cell Size</td>
          <td>
            <xsl:value-of select="tempuri:OriginalCellSize"/><xsl:text>&#xA0;</xsl:text>(<xsl:copy-of select="$DisplayUnits"/>)
        </td>
        </tr>
      </tbody>
    </table>
  </xsl:template>

  <!-- Template for each AssociatedSurfaces inside DEMSurvey nodes -->
  <xsl:template match="tempuri:AssociatedSurface">
    <div class="associatedSurface">
      <h4>
        <xsl:value-of select="tempuri:Name"/>
      </h4>
      <p>The following are the Associated surfaces generated from survey one used in the change detection analysis</p>
      <div class="row">
        <div class="surface-image columns medium-7">
          <img>
              <xsl:attribute name="src">Images/<xsl:value-of select ="tempuri:Name"/>_<xsl:value-of select="tempuri:AssociatedSurfaceID"/>.png</xsl:attribute>
          </img>
        </div>
        <div class="surface-table columns medium-5">
          <xsl:call-template name="SurfaceResultsTable" />
        </div>
      </div>
      <h5>Associated Surface Methodology - <xsl:value-of select ="tempuri:Name"/></h5>
          This section is dependent on the associated surface type and loads a brief description of the methodology and a link to the <a href="http://gcd6help.joewheaton.org/gcd-command-reference/gcd-project-explorer/d-dem-context-menu/iv-add-associated-surface/3-deriving-point-density" target="_blank">
      <b>GCD concepts page</b></a> or <a href="http://gcd6help.joewheaton.org/gcd-command-reference/gcd-project-explorer/d-dem-context-menu/iv-add-associated-surface/3-deriving-point-density" target="_blank">
      <b>other info like this.</b>
    </a>
        <!--<xsl:if test="tempuri:Type = 'Point Density'">
          Point density is calculated with the following <a href="http://gcd6help.joewheaton.org/gcd-command-reference/gcd-project-explorer/d-dem-context-menu/iv-add-associated-surface/3-deriving-point-density" target="_blank"><b>methods</b></a>
        </xsl:if>
      <xsl:if test="tempuri:Type = 'Slope Degrees'">
        Slope in degrees is calculated with the following <a href="http://resources.arcgis.com/en/help/main/10.1/index.html#//009z000000vz000000" target="_blank"><b>methods</b></a>
      </xsl:if>-->
    </div>
  </xsl:template>

  <!-- Template for each ErrorSurface inside DEMSurvey nodes -->
  <xsl:template match="tempuri:ErrorSurface">
    <div class="errorSurface">
      <h4>
        <xsl:value-of select="tempuri:Name"/>
      </h4>
      <p>The following are the Error Surfaces generated from survey one used in the change detection analysis</p>

      <div class="row">
        <div class="surface-image columns medium-7">
          <img>
            <xsl:attribute name="src">Images/<xsl:value-of select ="tempuri:Name"/>_<xsl:value-of select="tempuri:ErrorSurfaceID"/>.png</xsl:attribute>
          </img>
        </div>
        <div class="surface-table columns medium-5">
          <xsl:call-template name="SurfaceResultsTable" />
        </div>
      </div>
      <h5>
        Error Surface Methodology - <xsl:value-of select ="tempuri:Type"/>
      </h5>
      <xsl:if test="tempuri:Type = 'FIS'">
        <div class="row">
          <div class="text columns medium-6">
            The following FIS, <xsl:value-of select="tempuri:FISInputs/tempuri:FIS"/>, was used to calculate this error surface  <xsl:value-of select="tempuri:ErrorSurfaceID"/><b> methods</b>. Methodology and info <a href="http://gcd6help.joewheaton.org/gcd-concepts/fuzzy-inference-systems-for-modeling-dem-error" target="_blank">
              <b>can be found here.</b></a>
          </div>
          <div class="surface-table columns medium-6">
            <xsl:call-template name="FISInputsTable" />
          </div>
        </div>
      </xsl:if>
      <xsl:if test="tempuri:Type = 'Uniform Error'">
         A description of the methodology and concepts behind uniform error <a href="http://gcd6help.joewheaton.org/tutorials--how-to/v-thresholding-w-raster-calculator" target="_blank"><b>can be found here.</b></a>
      </xsl:if>

    </div>
  </xsl:template>

  <!-- Results Table: Generic stats about the surface images -->
  <xsl:template name="SurfaceResultsTable">
      <table class="surface-table">
        <thead>
          <tr>
            <th>Name</th>
            <th>Value</th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="*">
            <tr>
              <xsl:attribute name="class">name <xsl:value-of select ="name(.)"/></xsl:attribute>
              <td class="name">
                <xsl:value-of select ="name(.)"/>
              </td>
              <td class="value">
                <xsl:value-of select="."/>
              </td>
            </tr>
          </xsl:for-each>
        </tbody> 
      </table>
    </xsl:template>

  <!-- FIS Inputs Table-->
  <xsl:template name="FISInputsTable">
    <table class="fis-inputs-table">
      <thead>
        <tr>
          <th>Name</th>
          <th>Value</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <td>Error Surface ID</td>
          <td><xsl:value-of select="tempuri:ErrorSurfaceID"/></td>
        </tr>
        <tr>
          <td>FIS Name</td>
          <td><xsl:value-of select="tempuri:FISInputs/tempuri:FIS"/></td>
        </tr>
        <xsl:for-each select="tempuri:FISInputs">
          <tr>
            <td>Input ID</td>
            <td><xsl:value-of select="tempuri:FISInputsID"/></td>
          </tr>
          <tr>
            <td>FIS Input Type</td>
            <td>
              <xsl:value-of select="tempuri:FISInput"/>
            </td>
          </tr>
          <tr>
            <td>Associated Surface Used</td>
            <td>
              <xsl:value-of select="tempuri:AssociatedSurface"/>
            </td>
          </tr>
        </xsl:for-each>        
      </tbody>
      
    </table>
  </xsl:template>
  
  <!-- DEM of difference Template  -->
  <xsl:template match="tempuri:DoDs">
    <div class="dodSurface">
      <h3>
        <xsl:value-of select="tempuri:Name"/>
      </h3>
      <!--  Check to see the type of change detection and write intro accordingly-->
      <xsl:if test="tempuri:TypeMinLOD = 'true'">
        <xsl:call-template name="dodIntroMinLoD" />
      </xsl:if>
      <xsl:if test="tempuri:TypePropagated = 'true'">
        <xsl:copy-of select="$dodIntroPropagated"/>
      </xsl:if>
      <xsl:if test="tempuri:TypeProbabilistic = 'true'">
        <xsl:copy-of select="$dodIntroProbabilistic"/>
      </xsl:if>
      <p>The following are the DoD results for change detection analysis.</p>
      <div class="row">
        <div class="surface-image columns medium-7">
          <img class="dodSurfRaster lightbox">
            <xsl:attribute name="src">
              Images/<xsl:value-of select ="tempuri:Name"/>_<xsl:value-of select="tempuri:DoDID"/>.png
            </xsl:attribute>
          </img>
        </div>
        <div class="surface-table columns medium-5">
          <xsl:call-template name="ChangeDetectionPropertiesTable" />
        </div>
      </div>
      
      <div class ="row">
        <div class="columns medium-4">
          <img class="dodSurfAreaHist lightbox">
            <xsl:attribute name="src">
              Images/<xsl:value-of select ="tempuri:Name"/>AreaHist.png
            </xsl:attribute>
          </img>
        </div>
        <div class="columns medium-4">
          <img class="dodSurfVolumeHist lightbox">
            <xsl:attribute name="src">
              Images/<xsl:value-of select ="tempuri:Name"/>VolumeHist.png
            </xsl:attribute>
          </img>
        </div>
      </div>
      
      <div>
        <h4>Change Detection Summary Table</h4>
        <xsl:call-template name="DoDSummary" />   
      </div>
    </div>
  </xsl:template>

  <!-- The DoD summary table is complex -->
  <xsl:template name="DoDSummary">

    <!-- Areal Properties  -->
    <xsl:variable name="AreaErosion_Raw" select="tempuri:AreaErosionRaw" />
    <xsl:variable name="AreaDeposition_Raw" select="tempuri:AreaDepositonRaw" />
    <xsl:variable name="AreaErosion_Thresholded" select="tempuri:AreaErosionThresholded" />
    <xsl:variable name="AreaDeposition_Thresholded" select="tempuri:AreaDepositionThresholded" />
    <xsl:variable name="AreaDetectableChange_Thresholded" select="(tempuri:AreaDepositionThresholded+tempuri:AreaErosionThresholded)" />
    <xsl:variable name="AreaOfInterest_Raw" select="(tempuri:AreaDepositonRaw+tempuri:AreaErosionRaw)" />
    <xsl:variable name="AreaPercentAreaInterestWithDetectableChange" select="100 * (tempuri:AreaDepositionThresholded+tempuri:AreaErosionThresholded) div (tempuri:AreaDepositonRaw+tempuri:AreaErosionRaw)" />
 
    <!-- Volumetric Properties  -->
    <xsl:variable name="VolumeErosion_Raw" select="tempuri:VolumeErosionRaw" />
    <xsl:variable name="VolumeErosion_Thresholded" select="tempuri:VolumeErosionThresholded" />
    <xsl:variable name="VolumeErosion_ErrorRaw" select="number(tempuri:VolumeErosionError)" />
    <xsl:variable name="VolumeErosion_Error" select="user:GetAbs($VolumeErosion_ErrorRaw)" />
    <xsl:variable name="VolumeErosion_Error_Percent" select="(100 * $VolumeErosion_Error div $VolumeErosion_Thresholded)" />

    <xsl:variable name="VolumeDeposition_Raw" select="tempuri:VolumeDepositionRaw" />
    <xsl:variable name="VolumeDeposition_Thresholded" select="tempuri:VolumeDepositionThresholded" />
    <xsl:variable name="VolumeDeposition_ErrorRaw" select="number(tempuri:VolumeDepositionError)" />
    <xsl:variable name="VolumeDeposition_Error" select="user:GetAbs($VolumeDeposition_ErrorRaw)" />
    <xsl:variable name="VolumeDeposition_Error_Percent" select="(100 * $VolumeDeposition_Error div $VolumeDeposition_Thresholded)" />

    <xsl:variable name="VolumeOfDifference_Raw" select="(tempuri:VolumeErosionRaw + tempuri:VolumeDepositionRaw)" />
    <xsl:variable name="VolumeOfDifference_Thresholded" select="(tempuri:VolumeErosionThresholded + tempuri:VolumeDepositionThresholded)" />
    <xsl:variable name="VolumeOfDifference_Error" select="user:GetAbs(tempuri:VolumeErosionError + tempuri:VolumeDepositionError)" />
    <xsl:variable name="VolumeOfDifference_Error_Percent" select="(100 * $VolumeOfDifference_Error div $VolumeOfDifference_Thresholded)" />

    <xsl:variable name="NetVolumeOfDifference_Raw" select="(tempuri:VolumeDepositionRaw - tempuri:VolumeErosionRaw)" />
    <xsl:variable name="NetVolumeOfDifference_Thresholded" select="(tempuri:VolumeDepositionThresholded - tempuri:VolumeErosionThresholded)" />
    <xsl:variable name="NetVolumeOfDifference_Error" select="user:GetSqrt(user:GetAbs(($VolumeDeposition_Error * $VolumeDeposition_Error) + ($VolumeErosion_Error * $VolumeErosion_Error)))" />
    <xsl:variable name="NetVolumeOfDifference_Error_Percent" select="(100 * $NetVolumeOfDifference_Error div $NetVolumeOfDifference_Thresholded)" />

    <xsl:variable name="VolumeOfErosion_Percent" select="(100 * $VolumeErosion_Error div $NetVolumeOfDifference_Thresholded)" />
    <xsl:variable name="VolumeOfDeposition_Percent" select="(100 * $VolumeDeposition_Error div $NetVolumeOfDifference_Thresholded)" />
    <xsl:variable name="VolumeOfDifference_Percent" select="(100 * $VolumeOfDifference_Error div $NetVolumeOfDifference_Thresholded)" />
    <xsl:variable name="NetVolumeOfDifference_Percent" select="(100 * $NetVolumeOfDifference_Error div $NetVolumeOfDifference_Thresholded)" />

     <!-- Vertical Averages Erosion  -->
    <xsl:variable name="AverageDepthErosion_Raw" select="($VolumeErosion_Raw div $AreaErosion_Raw)" />
    <xsl:variable name="AverageDepthErosion_Thresholded" select="($VolumeErosion_Thresholded div $AreaErosion_Thresholded)" />
    <xsl:variable name="AverageDepthErosion_Error" select="user:GetAbs($VolumeErosion_Error div $AreaErosion_Thresholded)" />
    <xsl:variable name="AverageDepthErosion_Percent" select="(100 * $AverageDepthErosion_Error div $AverageDepthErosion_Thresholded)" />

     <!-- Vertical Averages Deposition  -->
    <xsl:variable name="AverageDepthDeposition_Raw" select="($VolumeDeposition_Raw div $AreaDeposition_Raw)" />
    <xsl:variable name="AverageDepthDeposition_Thresholded" select="($VolumeDeposition_Thresholded div $AreaDeposition_Thresholded)" />
    <xsl:variable name="AverageDepthDeposition_Error" select="user:GetAbs($VolumeDeposition_Error div $AreaDeposition_Thresholded)" />
    <xsl:variable name="AverageDepthDeposition_Percent" select="(100 * $AverageDepthDeposition_Error div $AverageDepthDeposition_Thresholded)" />

     <!-- Vertical Averages Total Thickness of Difference for AOI  -->
    <xsl:variable name="AverageThicknessOfDifferenceAOI_Raw" select="($VolumeOfDifference_Raw div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageThicknessOfDifferenceAOI_Thresholded" select="($VolumeOfDifference_Thresholded div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageThicknessOfDifferenceAOI_Error" select="user:GetAbs($VolumeOfDifference_Error div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageThicknessOfDifferenceAOI_Percent" select="(100 * $AverageThicknessOfDifferenceAOI_Error div $AverageThicknessOfDifferenceAOI_Thresholded)" />

    <!-- Vertical Averages **NET** Thickness of Difference for Area of Interest (AOI)  -->
    <xsl:variable name="AverageNetThicknessofDifferenceAOI_Raw" select="($NetVolumeOfDifference_Raw div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageNetThicknessOfDifferenceAOI_Thresholded" select="($NetVolumeOfDifference_Thresholded div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageNetThicknessOfDifferenceAOI_Error" select="($NetVolumeOfDifference_Error div $AreaOfInterest_Raw)" />
    <xsl:variable name="AverageNetThicknessOfDifferenceAOI_Percent" select="(100 * $AverageNetThicknessOfDifferenceAOI_Error div $AverageNetThicknessOfDifferenceAOI_Thresholded)" />

    <!-- Vertical Averages **NET** Thickness of Difference for Area of Dectectable Change (ADC)  -->
    <xsl:variable name="AverageThicknessOfDifferenceADC_Thresholded" select="($VolumeOfDifference_Thresholded div $AreaDetectableChange_Thresholded)" />
    <xsl:variable name="AverageThicknessOfDifferenceADC_Error" select="user:GetAbs($VolumeOfDifference_Error div $AreaDetectableChange_Thresholded)" />
    <xsl:variable name="AverageThicknessOfDifferenceADC_Percent" select="(100 * $AverageThicknessOfDifferenceADC_Error div $AverageThicknessOfDifferenceADC_Thresholded)" />

     <!-- Vertical Averages **Total** Thickness of Difference for Area of Detectable Change (ADC)  -->
    <xsl:variable name="AverageNetThicknessOfDifferenceADC_Thresholded" select="($NetVolumeOfDifference_Thresholded div $AreaDetectableChange_Thresholded)" />
    <xsl:variable name="AverageNetThicknessOfDifferenceADC_Error" select="user:GetAbs($NetVolumeOfDifference_Error div $AreaDetectableChange_Thresholded)" />
    <xsl:variable name="AverageNetThicknessOfDifferenceADC_Percent" select="(100 * $AverageNetThicknessOfDifferenceADC_Error div $AverageNetThicknessOfDifferenceADC_Thresholded)" />

     <!-- Percentages By Volume  -->
    <xsl:variable name="PercentErosion_Raw" select="(100 * $VolumeErosion_Raw div $VolumeOfDifference_Raw)" />
    <xsl:variable name="PercentErosion_Thresholded" select="(100 * $VolumeErosion_Thresholded div $VolumeOfDifference_Thresholded)" />
    <xsl:variable name="PercentDeposition_Raw" select="(100 * $VolumeDeposition_Raw div $VolumeOfDifference_Raw)" />
    <xsl:variable name="PercentDeposition_Thresholded" select="(100 * $VolumeDeposition_Thresholded div $VolumeOfDifference_Thresholded)" />
    <xsl:variable name="PercentImbalance_Raw" select="(100 * $NetVolumeOfDifference_Raw div (2 * $VolumeOfDifference_Raw))" />
    <xsl:variable name="PercentImbalance_Thresholded" select="(100 * $NetVolumeOfDifference_Thresholded div (2 * $VolumeOfDifference_Thresholded))" />
    <xsl:variable name="NetToTotalVolumeRatio_Raw" select="(100 * $NetVolumeOfDifference_Raw div $VolumeOfDifference_Raw)" />
    <xsl:variable name="NetToTotalVolumeRatio_Thresholded" select="(100 * $NetVolumeOfDifference_Thresholded div $VolumeOfDifference_Thresholded)" />

    <table class="DoDSummaryTable">
        <thead>
            <tr>
                <th>Attribute</th>
                <th colspan="3"> </th>
            </tr>
        </thead>
        <tbody>
            <tr class="DoDRowGroupHeader" >
                <th>Areal:</th>
                <th>Raw (<span class="dod-unit"><xsl:value-of select="$unit"/></span>²)</th> 
                <th colspan="3">Thresholded DoD Estimate (<span class="dod-unit"><xsl:value-of select="$unit"/></span>²)</th>
            </tr>
            <tr>
                <td class="rowname">
                  <span data-tooltip="" aria-haspopup="true" class="has-tip tip-bottom radius" title="The ammount of area experiencing erosion">
                    Total Area of Erosion</span>
                </td>
                <td><xsl:value-of select="format-number($AreaErosion_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($AreaErosion_Thresholded, '###,##0.0')" /></td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">
                  <span data-tooltip="" aria-haspopup="true" class="has-tip tip-bottom radius" title="The ammount of area experiencing deposition">
                    Total Area of Deposition
                  </span>
                </td>
                <td><xsl:value-of select="format-number($AreaDeposition_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($AreaDeposition_Thresholded, '###,##0.0')" /></td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Total Area of Detectable Change</td>
                <td>NA</td>
                <td>
                  <xsl:value-of select="format-number($AreaDetectableChange_Thresholded, '###,##0.0')" />
                </td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Total Area of Interest</td>
                <td><xsl:value-of select="format-number($AreaOfInterest_Raw, '###,##0.0')" /></td>
                <td>NA</td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Percent of Area Of Interest with Detectable Change</td>
                <td>NA</td>
                <td><xsl:value-of select="format-number($AreaPercentAreaInterestWithDetectableChange, '###,##0.0')" />%</td>
                <td colspan="2"> </td>
            </tr>
            <tr class="DoDRowGroupHeader">
                <th>Volumetric:</th>
                <th>Raw (<span class="dod-unit"><xsl:value-of select="$unit"/></span>³)</th> 
                <th></th>
                <th>± Error Volume (<span class="dod-unit"><xsl:value-of select="$unit"/></span>³)</th>
                <th>% Error (<span class="dod-unit"><xsl:value-of select="$unit"/></span>³)</th>
            </tr>
            <tr>
                <td class="rowname">Total Volume of Erosion</td>
                <td><xsl:value-of select="format-number($VolumeErosion_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($VolumeErosion_Thresholded, '###,##0.0')" /></td>
                <td>± <xsl:value-of select="format-number($VolumeErosion_Error, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($VolumeErosion_Error_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Total Volume of Deposition</td>
                <td><xsl:value-of select="format-number($VolumeDeposition_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($VolumeDeposition_Thresholded, '###,##0.0')" /></td>
                <td>± <xsl:value-of select="format-number($VolumeDeposition_Error, '###,##0.0')" /></td> 
                <td><xsl:value-of select="format-number($VolumeDeposition_Error_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Total Volume of Difference</td>
                <td><xsl:value-of select="format-number($VolumeOfDifference_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($VolumeOfDifference_Thresholded, '###,##0.0')" /></td>
                <td>± <xsl:value-of select="format-number($VolumeOfDifference_Error, '###,##0.0')" /></td> 
                <td><xsl:value-of select="format-number($VolumeOfDifference_Error_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Total Net Volume of Difference</td>
                <td><xsl:value-of select="format-number($NetVolumeOfDifference_Raw, '###,##0.0')" /></td>
                <td><xsl:value-of select="format-number($NetVolumeOfDifference_Thresholded, '###,##0.0')" /></td>
                <td>± <xsl:value-of select="format-number($NetVolumeOfDifference_Error, '###,##0.0')" /></td> 
                <td><xsl:value-of select="format-number($NetVolumeOfDifference_Error_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr class="DoDRowGroupHeader">
                <th>Vertical Averages:</th>
                <th>Raw (<span class="dod-unit"><xsl:value-of select="$unit"/></span>)</th>
                <th></th>
                <th>± Error Volume (<span class="dod-unit"><xsl:value-of select="$unit"/></span>³)</th>
                <th>% Error (<span class="dod-unit"><xsl:value-of select="$unit"/></span>³)</th>
            </tr>
            <tr>
                <td class="rowname">Average Depth of Erosion</td>
                <td><xsl:value-of select="format-number($AverageDepthErosion_Raw, '###,##0.000')" /></td>
                <td><xsl:value-of select="format-number($AverageDepthErosion_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageDepthErosion_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageDepthErosion_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Average Depth of Deposition</td>
                <td><xsl:value-of select="format-number($AverageDepthDeposition_Raw, '###,##0.000')" /></td>
                <td><xsl:value-of select="format-number($AverageDepthDeposition_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageDepthDeposition_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageDepthDeposition_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Average Total Thickness Of Difference for Area of
                Interest</td>
                <td><xsl:value-of select="format-number($AverageThicknessOfDifferenceAOI_Raw, '###,##0.000')" /></td>
                <td><xsl:value-of select="format-number($AverageThicknessOfDifferenceAOI_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageThicknessOfDifferenceAOI_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageThicknessOfDifferenceAOI_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Average Net Thickness Of Difference for Area of Interest</td>
                <td><xsl:value-of select="format-number($AverageNetThicknessofDifferenceAOI_Raw, '###,##0.000')" /></td>
                <td><xsl:value-of select="format-number($AverageNetThicknessOfDifferenceAOI_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageNetThicknessOfDifferenceAOI_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageNetThicknessOfDifferenceAOI_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Average Total Thickness Of Difference for Area with Detectable Change</td>
                <td>NA</td>
                <td><xsl:value-of select="format-number($AverageThicknessOfDifferenceADC_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageThicknessOfDifferenceADC_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageThicknessOfDifferenceADC_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr>
                <td class="rowname">Average Net Thickness Of Difference for Area with
                Detectable Change</td>
                <td>NA</td>
                <td><xsl:value-of select="format-number($AverageNetThicknessOfDifferenceADC_Thresholded, '###,##0.000')" /></td>
                <td>± <xsl:value-of select="format-number($AverageNetThicknessOfDifferenceADC_Error, '###,##0.00')" /></td> 
                <td><xsl:value-of select="format-number($AverageNetThicknessOfDifferenceADC_Percent, '###,##0.00')" />%</td>
            </tr>
            <tr class="DoDRowGroupHeader">
                <th>Percentages (by Volume):</th>
                <th>Raw</th>
                <th colspan="3">Thresholded DoD Estimate</th>
            </tr>
            <tr>
                <td class="rowname">Percent Erosion</td>
                <td><xsl:value-of select="format-number($PercentErosion_Raw, '###,##0.0')" />%</td>
                <td><xsl:value-of select="format-number($PercentErosion_Thresholded, '###,##0.0')" />%</td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Percent Deposition</td>
                <td><xsl:value-of select="format-number($PercentDeposition_Raw, '###,##0.0')" />%</td>
                <td><xsl:value-of select="format-number($PercentDeposition_Thresholded, '###,##0.0')" />%</td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Percent Imbalance (departure from equilibrium)</td>
                <td><xsl:value-of select="format-number($PercentImbalance_Raw, '###,##0.0')" />%</td>
                <td><xsl:value-of select="format-number($PercentImbalance_Thresholded, '###,##0.0')" />%</td>
                <td colspan="2"> </td>
            </tr>
            <tr>
                <td class="rowname">Net to Total Volume Ratio</td>
                <td><xsl:value-of select="format-number($NetToTotalVolumeRatio_Raw, '###,##0.0')" />%</td>
                <td><xsl:value-of select="format-number($NetToTotalVolumeRatio_Thresholded, '###,##0.0')" />%</td>
                <td colspan="2"> </td>
            </tr>
        </tbody>
    </table>
  </xsl:template>


  <!-- Template for Change Detection Properties  -->
  <xsl:template name="ChangeDetectionPropertiesTable">
    <table class="surface-table">
      <thead>
        <tr>
          <th>Name</th>
          <th>Value</th>
        </tr>
      </thead>
      <tbody>
        <tr>
          <td>New DEM Survey</td>
          <td>
            <xsl:value-of select="tempuri:NewSurveyName"/>
          </td>
        </tr>
        <tr>
          <td>Old DEM Survey</td>
          <td>
            <xsl:value-of select="tempuri:OldSurveyName"/>
          </td>
        </tr>
        <tr>
          <td>Raw DoD</td>
          <td>
            <xsl:value-of select="tempuri:RawDoDPath"/>
          </td>
        </tr>
        <tr>
          <td>Thresholded DoD</td>
          <td>
            <xsl:value-of select="tempuri:ThreshDoDPath"/>
          </td>
        </tr>
        <xsl:if test="tempuri:TypeMinLOD = 'true'">
          <tr>
            <td>Thresholding Method</td>
            <td>
              Minimum Level of Detection
            </td>
          </tr>
          <tr>
            <td>Minimum Level of Detection</td>
            <td><xsl:value-of select="tempuri:Threshold"/><xsl:text>&#xA0;</xsl:text>(<xsl:copy-of select="$DisplayUnits"/>)
          </td>
          </tr>
        </xsl:if>
        <xsl:if test="tempuri:TypePropagated = 'true'">
          <tr>
            <td>Thresholding Method</td>
            <td>
              Propagated Error
            </td>
          </tr>
          <tr>
            <td>Error Surface Path</td>
            <td>
              <xsl:value-of select="tempuri:PropagatedErrorRasterPath"/>
            </td>
          </tr>
        </xsl:if>
        <xsl:if test="tempuri:TypeProbabilistic = 'true'">
          <tr>
            <td>Thresholding Method</td>
            <td>
              Probabilistic Thresholding
            </td>
          </tr>
          <tr>
            <td>Error Surface Path</td>
            <td>
              <xsl:value-of select="tempuri:ProbabilityRaster"/>
            </td>
          </tr>
        </xsl:if>
        <xsl:if test="tempuri:Bayesian = 'true'">
          <tr>
            <td>Bayesian Updating</td>
            <td>Yes</td>
          </tr>
          <tr>
            <td>Spatial Coherence Properties</td>
            <td>
              <xsl:value-of select="tempuri:Filter"/> x <xsl:value-of select="tempuri:Filter"/> filter with breaks at <xsl:value-of select="tempuri:PercentLess"/>% and <xsl:value-of select="tempuri:PercentMore"/>%
            </td>
          </tr>
        </xsl:if>
        <xsl:if test="tempuri:Bayesian = 'false'">
          <tr>
            <td>Bayesian Updating</td>
            <td>No</td>
          </tr>
        </xsl:if>         
      </tbody>
    </table>
  </xsl:template>
  
  <!-- For Appendices and acknowledgements we load an external file: -->
  <xsl:template name="Appendices">
    <!-- To import an HTML file: -->
    <xsl:variable name="htmlFooter" select="document($sFooterPath)"/>
    <xsl:copy-of select="$htmlFooter/*/node()"/>
  </xsl:template>

  <xsl:variable name="GCDVersion">
    <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:GCDVersion"/>
  </xsl:variable>

  <xsl:variable name="DisplayUnits">
    <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:DisplayUnits"/>
  </xsl:variable>
  
  <xsl:variable name="associatedSurfaceIntro">
    Associated surfaces are rasters that represent additional information about your survey.
    They are used in the calculation of error rasters. Each associated surface is represented
    as a single raster dataset and is a input into an FIS. Associated surfaces include:
    point density, roughness, and slope analysis.
  </xsl:variable>

  <xsl:variable name="errorSurfaceIntro">
    Each survey can have multiple DEM error calculation rasters.
    There are four types of error rasters in the GCD: uniform error,
    user defined error rasters, spatially variable error based on a fuzzy inference system,
    and hybrid error mixing (either uniform error values or uniform error values with
    fuzzy inference system values.
  </xsl:variable>

  <xsl:template name="dodIntroMinLoD">
    For this change detection analysis a Thresholding Change Detection with simple minimum level of detection was performed in GCD <xsl:copy-of select="$GCDVersion"/> software.
    The threshold used was <xsl:value-of select="tempuri:Threshold"/><xsl:text>&#xA0;</xsl:text>(<xsl:copy-of select="$DisplayUnits"/>).
  </xsl:template>
  
  <xsl:variable name="dodIntroPropagated">
    For this change detection analysis a spatially uniform error propagation was performed using GCD <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:GCDVersion"/> software.
    This assumes errors to be spatially uniform, but can vary temporally. The output of this change detection analysis is found is shown below.
  </xsl:variable>

  <xsl:variable name="dodIntroProbabilistic">
    For this change detection analysis probabilistic thresholding was performed using GCD <xsl:value-of select="tempuri:ProjectDS/tempuri:Project/tempuri:GCDVersion"/> software.
    The output of this change detection analysis is found here:
  </xsl:variable>

 
</xsl:stylesheet>