module.exports = function(grunt) {
  grunt.initConfig({
    pkg: grunt.file.readJSON('package.json'),
    // Run compass
    // All the parameters below replace config.rb.
   compass: {
      options: {
        watch: false,
        cssDir: '../dist',
        sassDir: 'scss',
        imagesDir: 'img',
        javascriptsDir: 'js',
        fontsDir: 'fonts',
        httpPath: '/',
        relativeAssets: true,
        noLineComments: true,
        importPath: [
          'bower_components/foundation/scss'
        ],
      },
      dist: {
        options: {
          environment: 'production',
          outputStyle: 'compressed',
        },
      },
      dev: {
        options: {
          environment: 'development',
          outputStyle: 'nested',
        },
      },
    },

    // Move our assets out of bower_components
    copy: {
      bowerlibs: {
        files: [
          { expand:true, cwd:'bower_components/foundation/js/', src:'foundation.min.js', dest: 'js/vendor/' },
          { expand:true, cwd:'bower_components/jquery/dist/',   src:'jquery.min.js', dest: 'js/vendor/' },
          { expand:true, cwd:'bower_components/toc/dist/',      src:'toc.min.js', dest: 'js/vendor/' }
        ],
      },
      deploy: {
        files: [
          { expand:true, cwd:'bower_components/modernizr/', src:'modernizr.js', dest: '../dist/js' },
        ],
      },
    },

    // Collect all our js into one script
    concat: {
        options: {
          separator: '\n;\n',
          stripBanners: true,
          banner: '/*! <%= pkg.name %> - v<%= pkg.version %> - ' +
            '<%= grunt.template.today("yyyy-mm-dd") %> */',
        },
        dist: {
          src: [
            'js/vendor/jquery.min.js', 
            'js/vendor/jquery.nearest.js',
            'js/vendor/foundation.min.js',
            'js/vendor/toc.min.js',
            'js/app.js',
          ],
          dest: '../dist/js/report.js',
        },
      },

      // Apply the XSL transform
      xsltproc: {
        options: {
          stylesheet: '../dist/GCDReportTemplate.xsl'
        },
        compile: {
          files:{
            '../dist/preview.html': ['sample.gcd']
          }
          
        }
      },


    // This is for dev only. Makes use of livereload on file changes.
    watch: {
      site: {
        files: [
          '../dist/**', 
        ],
        options: { livereload: true}
      },
      scss: {
        files: ['scss/**.scss'],
        tasks: ['compass:dist'],
      },
      xsl: {
        files: ['../dist/GCDReportTemplate.xsl'],
        tasks: ['xsltproc'],
      },
      js: {
        files: ['js/**'],
        tasks: ['concat'],
      },
    }
  });

  // Define the modules we need for these tasks:
  grunt.loadNpmTasks('grunt-contrib-compass');
  grunt.loadNpmTasks('grunt-contrib-concat');
  grunt.loadNpmTasks('grunt-contrib-copy');
  grunt.loadNpmTasks('grunt-contrib-watch');
  grunt.loadNpmTasks('grunt-xsltproc');

  // Here are our tasks 
  grunt.registerTask('default', [ 'build' ]);
  grunt.registerTask('build', [ 'copy', 'compass:dist', 'concat', 'copy:deploy']);
  grunt.registerTask('dev', [ 'watch' ]);

};